/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMElement.idl"
#include "nsIDOMXULElement.idl"

[scriptable, uuid(d7967c4e-60e1-486d-a730-c25b285f0ffa)]
interface nsIDOMXULImageElement : nsIDOMXULElement {
  attribute DOMString src;
};

